Loads the cached Vascular Plant Japanese Name Checklist ver. 1.10 as a data frame normalized for the package lookup helpers. If the cache does not exist, the checklist file is downloaded first.
Loads the cached Vascular Plant Japanese Name Checklist ver. 1.10 as a data frame normalized for the package lookup helpers. If the cache does not exist, the checklist file is downloaded first.